#------------------------------------------------------------------------------------------------
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#------------------------------------------------------------------------------------------------
#    Name:	RTD - Roll The Dice
#      By:	sdmitch
#   Usage:	Randomly replace the "Target" components with a "Source" component.
#	 Note:	All "Target" components MUST have the same name or prefix and all "Source" components MUST 
#			have the same name or prefix.  All "Target" components are randomly replaced by a "Source".
#			If some are selected, then only those are replaced.  The "Target" component can be anything
#			and can all be copies of a single component.  THE COMPONENT NAME, NOT THE COMPONENT
#			DEFINITION NAME IS USED FOR IDENTIFICATION OF THE "Source" AND "Target" COMPONENTS.  You
#			can access the component name through Entity Info.
#    Date:	Jun 2011
#------------------------------------------------------------------------------------------------

require 'Sketchup'

module RTD

	def self.replace_targets
		mod=Sketchup.active_model
		ent=mod.entities
		sel=mod.selection
		@source_name = "Source" if !@source_name;@target_name = "Target" if !@target_name
		ans=UI.inputbox(["Source Name/Prefix:","Target Name/Prefix:"],[@source_name,@target_name],"Random Replacement")
		return nil if !ans
		@source_name,@target_name=ans
		if @source_name==@target_name
			UI.messagebox "The source and target names must be different"
			return nil
		end
		# get the source component definitions
		source_components=[]
		for e in ent
			if e.is_a? Sketchup::ComponentInstance
				if e.name[0...@source_name.length]==@source_name
					source_components.push e
				end
			end
		end
		#get the target components definitions
		target_components=[]; sel = ent if sel.empty?
		for e in sel
			if e.is_a? Sketchup::ComponentInstance
				if e.name[0...@target_name.length]==@target_name
					target_components.push e
				end
			end
		end
		for b in target_components
			i=rand(source_components.length)
			b.definition=source_components[i].definition
		end
	end
	
end

filename=File.basename(__FILE__)

if !file_loaded?(filename)
	UI.menu("plugins").add_item("Random Replacement") { RTD.replace_targets }
end

file_loaded(filename)
